@@ -40,8 +40,8 @@ class Run(object):
         if arguments['command'] == "clone":
             retval = os.getcwd()
             print(retval)
-            list_files = subprocess.run(["git clone https://dagshub.com/gagan3012/summarization.git"])
-            os.chdir('/summarization')
+            list_files = subprocess.run(["git", "clone", "https://dagshub.com/gagan3012/summarization.git"])
+            os.chdir('./summarization/')
             return list_files.returncode
 
         retval = os.getcwd()
